@@ -1,4 +1,12 @@
-"Main interface for ce service type defs"
+"""
+Main interface for ce service type definitions.
+
+Usage::
+
+    from mypy_boto3.ce.type_defs import CostCategoryValuesTypeDef
+
+    data: CostCategoryValuesTypeDef = {...}
+"""
 import sys
 from typing import Dict, List
 
@@ -12,6 +20,87 @@ else:
     from typing_extensions import TypedDict
 
 
+__all__ = (
+    "CostCategoryValuesTypeDef",
+    "DimensionValuesTypeDef",
+    "TagValuesTypeDef",
+    "ExpressionTypeDef",
+    "CostCategoryRuleTypeDef",
+    "CreateCostCategoryDefinitionResponseTypeDef",
+    "DateIntervalTypeDef",
+    "DeleteCostCategoryDefinitionResponseTypeDef",
+    "CostCategoryTypeDef",
+    "DescribeCostCategoryDefinitionResponseTypeDef",
+    "GroupDefinitionTypeDef",
+    "MetricValueTypeDef",
+    "GroupTypeDef",
+    "ResultByTimeTypeDef",
+    "GetCostAndUsageResponseTypeDef",
+    "GetCostAndUsageWithResourcesResponseTypeDef",
+    "ForecastResultTypeDef",
+    "GetCostForecastResponseTypeDef",
+    "DimensionValuesWithAttributesTypeDef",
+    "GetDimensionValuesResponseTypeDef",
+    "CoverageCostTypeDef",
+    "CoverageHoursTypeDef",
+    "CoverageNormalizedUnitsTypeDef",
+    "CoverageTypeDef",
+    "ReservationCoverageGroupTypeDef",
+    "CoverageByTimeTypeDef",
+    "GetReservationCoverageResponseTypeDef",
+    "ReservationPurchaseRecommendationMetadataTypeDef",
+    "EC2InstanceDetailsTypeDef",
+    "ESInstanceDetailsTypeDef",
+    "ElastiCacheInstanceDetailsTypeDef",
+    "RDSInstanceDetailsTypeDef",
+    "RedshiftInstanceDetailsTypeDef",
+    "InstanceDetailsTypeDef",
+    "ReservationPurchaseRecommendationDetailTypeDef",
+    "ReservationPurchaseRecommendationSummaryTypeDef",
+    "EC2SpecificationTypeDef",
+    "ServiceSpecificationTypeDef",
+    "ReservationPurchaseRecommendationTypeDef",
+    "GetReservationPurchaseRecommendationResponseTypeDef",
+    "ReservationAggregatesTypeDef",
+    "ReservationUtilizationGroupTypeDef",
+    "UtilizationByTimeTypeDef",
+    "GetReservationUtilizationResponseTypeDef",
+    "RightsizingRecommendationMetadataTypeDef",
+    "RightsizingRecommendationSummaryTypeDef",
+    "EC2ResourceDetailsTypeDef",
+    "ResourceDetailsTypeDef",
+    "EC2ResourceUtilizationTypeDef",
+    "ResourceUtilizationTypeDef",
+    "CurrentInstanceTypeDef",
+    "TargetInstanceTypeDef",
+    "ModifyRecommendationDetailTypeDef",
+    "TerminateRecommendationDetailTypeDef",
+    "RightsizingRecommendationTypeDef",
+    "GetRightsizingRecommendationResponseTypeDef",
+    "SavingsPlansCoverageDataTypeDef",
+    "SavingsPlansCoverageTypeDef",
+    "GetSavingsPlansCoverageResponseTypeDef",
+    "SavingsPlansPurchaseRecommendationMetadataTypeDef",
+    "SavingsPlansDetailsTypeDef",
+    "SavingsPlansPurchaseRecommendationDetailTypeDef",
+    "SavingsPlansPurchaseRecommendationSummaryTypeDef",
+    "SavingsPlansPurchaseRecommendationTypeDef",
+    "GetSavingsPlansPurchaseRecommendationResponseTypeDef",
+    "SavingsPlansAmortizedCommitmentTypeDef",
+    "SavingsPlansSavingsTypeDef",
+    "SavingsPlansUtilizationTypeDef",
+    "SavingsPlansUtilizationAggregatesTypeDef",
+    "SavingsPlansUtilizationDetailTypeDef",
+    "GetSavingsPlansUtilizationDetailsResponseTypeDef",
+    "SavingsPlansUtilizationByTimeTypeDef",
+    "GetSavingsPlansUtilizationResponseTypeDef",
+    "GetTagsResponseTypeDef",
+    "GetUsageForecastResponseTypeDef",
+    "CostCategoryReferenceTypeDef",
+    "ListCostCategoryDefinitionsResponseTypeDef",
+    "UpdateCostCategoryDefinitionResponseTypeDef",
+)
+
 CostCategoryValuesTypeDef = TypedDict(
     "CostCategoryValuesTypeDef", {"Key": str, "Values": List[str]}, total=False
 )
